

.. only:: not latex

    Uporabljeni akronimi
    ======================


.. raw:: latex

    \chapter*{Uporabljeni akronimi}


.. list-table::
    :header-rows: 1
    :align: left

    - 
      + Akronim
      + Pomen

    - 
      + API
      + Application Programming Interface

    - 
      + CSV
      + Comma-Separated Values

    -
      + GPT
      + Generative Pre-trained Transformer

    -
      + GUI
      + Graphical User Interface

    -
      + HTTP
      + HyperText Transfer Protocol

    -
      + JSON
      + JavaScript Object Notation

    -
      + NFT
      + Non-Fungible Token

    - 
      + ORM
      + Object Relational Mapping

    -
      + PIP
      + Preferred Installer Program

    -
      + RAM
      + Random Access Memory

    -
      + SQL
      + Structured Query Language


.. only:: not latex

    Uporabljeni pojmi
    ======================


.. raw:: latex

    \chapter*{Uporabljeni pojmi}

.. list-table::
    :header-rows: 1
    :align: left

    - 
      + SLO
      + ENG

    - 
      + Asinhrona komunikacija
      + Async I/O

    -
      + Avtomatsko odkrivanje
      + Automatic discovery

    -
      + (GUI) Pripomočki
      + (GUI) Widgets

    - 

      + Sočasna večopravilnost
      + Concurrent multitasking

    - 
      + Izvorna koda
      + Source code

    - 
      + Nadzor verzij
      + Version control

    -
      + Nezamenljivi žetoni
      + Non-fungible tokens

    -
      + Omejevanje zahtev
      + Rate limiting

    -
      + Ovoj API
      + API wrapper

    - 
      + Pridružna povezava
      + Invite link

    - 
      + Prožilec
      + Trigger

    - 
      + Pritrditev
      + Fixture

    - 
      + Robot
      + Bot

    - 
      + Veriga blokov
      + Blockchain

    - 
      + Vgrajeno sporočilo
      + Embedded message

    -
      + Zahtevek za združitev vej
      + Pull request
